@@ -2,7 +2,7 @@ package Geo::Google::StaticMaps::V2::Visible;
 use warnings;
 use strict;
 use base qw{Package::New};
-our $VERSION = '0.07';
+our $VERSION = '0.12';
 our $PACKAGE = __PACKAGE__;
 
 =head1 NAME
@@ -48,20 +48,29 @@ sub stringify {
   my $self=shift;
   my @p=();
   push @p, $self->_styles;
-  foreach my $location ($self->locations) {
-    my $string="";
-    if (ref($location) eq "HASH") {
-      $string=sprintf("%0.6f,%0.6f", $location->{"lat"}, $location->{"lon"});
-    } elsif (ref($location) eq "ARRAY") {
-      $string=sprintf("%0.6f,%0.6f", @$location);
-    } else {
-      $string="$location"; #or any object that overloads
-    }
-    push @p, $string;
-  }
+  push @p, $self->_stringify_locations;
   return join "|", @p;
 }
 
+sub _stringify_locations {
+  my $self    = shift;
+  if ($self->can("encode") and $self->encode == 1) { #polygon encode support
+    return $self->_encode_locations;
+  } else {
+    my @strings = ();
+    foreach my $location ($self->locations) {
+      if (ref($location) eq "HASH") {
+        push @strings, sprintf("%0.6f,%0.6f", $location->{"lat"}, $location->{"lon"});
+      } elsif (ref($location) eq "ARRAY") {
+        push @strings, sprintf("%0.6f,%0.6f", @$location); #[$lat,$lon]
+      } else {
+        push @strings, "$location"; #or any object that overloads
+      }
+    }
+    return join "|", @strings;
+  }
+}
+
 =head2 locations
 
 Returns the locations array which can be set upon construction.
@@ -85,6 +94,8 @@ sub _styles {
 =head2 addLocation
 
   $marker->addLocation("Clifton, VA");
+  $marker->addLocation({lat=>38.7802903, lon=>-77.3867659});
+  $marker->addLocation([38.7802903, -77.3867659]);
 
 =cut
 
